==> haskell-hashable-time-0.3-212-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hashable-time
version:              0.3
visibility:           public
id:                   hashable-time-0.3-3Hxit0mCD7aLsrfzLucwwg
key:                  hashable-time-0.3-3Hxit0mCD7aLsrfzLucwwg
license:              BSD-3-Clause
maintainer:           Alexey Karakulov <ankarakulov@gmail.com>
author:               Alexey Karakulov <ankarakulov@gmail.com>
synopsis:             Hashable instances for Data.Time
description:          Hashable instances for types in Data.Time
category:             Data
abi:                  c1d769fd01489eb34f238e8b3d9902ea
exposed:              True
exposed-modules:      Data.Hashable.Time
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hashable-time
hs-libraries:         HShashable-time-0.3-3Hxit0mCD7aLsrfzLucwwg
depends:
    base-4.18.2.1 time-compat-1.9.8-BODxBHTzOg9HC7n472DQ2d

haddock-interfaces:
    /usr/share/doc/haskell-hashable-time/html/hashable-time.haddock

haddock-html:         /usr/share/doc/haskell-hashable-time/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hashable-time-0.3-213-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hashable-time
version:              0.3
visibility:           public
id:                   hashable-time-0.3-3oModGDL2asIJBTzCOmGbe
key:                  hashable-time-0.3-3oModGDL2asIJBTzCOmGbe
license:              BSD-3-Clause
maintainer:           Alexey Karakulov <ankarakulov@gmail.com>
author:               Alexey Karakulov <ankarakulov@gmail.com>
synopsis:             Hashable instances for Data.Time
description:          Hashable instances for types in Data.Time
category:             Data
abi:                  482f877b11d1fcd6085a5a05128d36f3
exposed:              True
exposed-modules:      Data.Hashable.Time
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hashable-time
hs-libraries:         HShashable-time-0.3-3oModGDL2asIJBTzCOmGbe
depends:
    base-4.18.2.1 time-compat-1.9.8-7O04Ol4OP6kGDX77tZ7Ltn

haddock-interfaces:
    /usr/share/doc/haskell-hashable-time/html/hashable-time.haddock

haddock-html:         /usr/share/doc/haskell-hashable-time/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
